@@ -950,6 +950,7 @@ html_view_pend_cursor_blink (HtmlView *view)
 					       blink_cb,
 					       view);
 		html_view_set_blink_timeout (view, blink_timeout);
+		html_view_set_cursor_visible (view, 0);
 		show_cursor (view);
  	}
 }
@@ -3227,7 +3228,7 @@ html_view_focus_element (HtmlView *view)
 
 				text = HTML_BOX_TEXT (box->children);
 				if (html_view_get_offset_for_box_text (view, text, &offset)) {
-					move_cursor (view, text, offset, FALSE);
+					move_cursor (view, HTML_BOX (text), offset, FALSE);
 					html_view_pend_cursor_blink (view);
 					html_view_check_cursor_blink (view);
 				}
